set echo off;
set tab off;
set linesize 85;
set pagesize 400;
spool repinfo.lst;

/************************************************************************************
*                                                                                   *
*   repinfo.sql        SILVERRUN ENTERPRISE BPM/RDM 2.8        Grandite             *
*   27-06-2003         SILVERRUN ENTREPRISE DFD/MRD 2.8        Grandite             *
*                                                                                   *
*************************************************************************************
*                                                                                   *
*   Connect under:                              Se connecter sous:                  *
*                                                                                   *
*   User with DBA privileges.                   Utilisateur ayant les privileges    *
*                                               d'un DBA.                           *
*                                                                                   *
*************************************************************************************
*                                                                                   *
*   Description:                                Description:                        *
*                                                                                   *
*   This script produces two result files.      Ce script produit deux fichiers:    *
*   REPINFO.LST contains information to         REPINFO.LST montre des informations *
*   ensure that the installation of the         permettant de s'assurer que         *
*   Repository has been done successfully.      l'installation du Referentiel est   *
*   REPSPACE.LST is a report on space           complete.                           *
*   allocated for the Silverrun Repository      REPSPACE.LST est un rapport sur     *
*   by object owned by SR_ADMIN.                l'espace alloue pour le Referentiel *
*                                               Silverrun par objet appartenant a   *
*                                               SR_ADMIN.                           *
*                                                                                   *
*   The Repository must contain                 Le Referentiel doit contenir        *
*   150 tables and 513 indexes.                 150 tables et 513 index.            *
*                                                                                   *
*                                                                                   *
*   YOU CAN MODIFY THIS SCRIPT BEFORE           VOUS POUVEZ MODIFIER CE SCRIPT      *
*   ITS FIRST RUN:                              AVANT SA PREMIERE EXECUTION :       *
*                                                                                   *
*   If you are not using the role names         Si vous n'utilisez pas les noms de  *
*   SR_USERS and SR_GUESTS you must modify      "role" SR_USERS et SR_GUESTS vous   *
*   them in this script.                        devez les modifier dans ce script.  *
*                                                                                   *
*   If you are not using the tablespace         Si vous n'utilisez pas les noms de  *
*   names SILVERRUN_REPOSITORY_DATA and         "tablespace"                        *
*   SILVERRUN_REPOSITORY_INDEXES you must       SILVERRUN_REPOSITORY_DATA et        *
*   modify them in this script.                 SILVERRUN_REPOSITORY_INDEXES vous   *
*                                               devez les modifier dans ce script.  *
*                                                                                   *
*   If you are not using the user SR_ADMIN      Si vous n'utilisez pas le "user"    *
*   as owner of the Repository tables you       SR_ADMIN comme "owner" des tables   *
*   must modify it in this script.              du Referentiel vous devez le        *
*                                               modifier dans ce script.            *
*                                                                                   *
************************************************************************************/

SELECT 'SILVERRUN REPOSITORY INFORMATION ON '||SYSDATE " " FROM DUAL;

/************************************************************************************
CONTENTS OF ZMODULE :                                                              */
select * from sr_admin.zModule;

/************************************************************************************
INFO ABOUT TABLESPACES :                                                           */
select TABLESPACE_NAME, STATUS from DBA_TABLESPACES
	where TABLESPACE_NAME IN ('SILVERRUN_REPOSITORY_DATA','SILVERRUN_REPOSITORY_INDEXES');
	   
/************************************************************************************
INFO ABOUT DATA FILES :                                                            */
select * from DBA_DATA_FILES
	where TABLESPACE_NAME IN ('SILVERRUN_REPOSITORY_DATA','SILVERRUN_REPOSITORY_INDEXES');
 
/************************************************************************************
FREE SPACE IN SILVERRUN_REPOSITORY_DATA AND SILVERRUN_REPOSITORY_INDEXES TABLESPACES: */
select TABLESPACE_NAME, sum(BYTES) "BYTES", sum(BLOCKS) "BLOCKS" from DBA_FREE_SPACE 
	where TABLESPACE_NAME IN ('SILVERRUN_REPOSITORY_DATA','SILVERRUN_REPOSITORY_INDEXES')
	group by TABLESPACE_NAME;
 
/************************************************************************************
SILVERRUN ROLES AND USERS :                                                        */
select GRANTED_ROLE, GRANTEE 
from DBA_ROLE_PRIVS
where GRANTED_ROLE in ('SR_USERS','SR_GUESTS')
	and GRANTEE <> 'SYSTEM'
order by GRANTED_ROLE, GRANTEE;
	 
/************************************************************************************
LIST OF SR_USERS'S PRIVILEGES WITHIN THE SILVERRUN REPOSITORY :
THERE SHOULD BE A LIST OF 150 TABLES */
select 	SUBSTR(TABLE_NAME,1,20) "TABLE NAME", SUBSTR(OWNER,1,20) "TABLE OWNER",
		SUBSTR(GRANTEE,1,20) "ROLE",
		SELECT_PRIV, INSERT_PRIV, UPDATE_PRIV, DELETE_PRIV
	from TABLE_PRIVILEGES
	where GRANTEE = 'SR_USERS'
	and upper(TABLE_NAME) in
	(
		'dCell',
		'dCpnProc',
		'dCpnStor',
		'dDiag',
		'dDispDes',
		'dExEnGR',
		'dExEnPrs',
		'dExtEnt',
		'dFigure',
		'dFigurGR',
		'dFlow',
		'dFlowGR',
		'dFont',
		'dFText',
		'dFTextGR',
		'dGrapRep',
		'dLabelGR',
		'dLine',
		'dLineGR',
		'dLinkGR',
		'dNode',
		'dPictGR',
		'dPicture',
		'dProcess',
		'dProcFrm',
		'dProcGR',
		'dProcPrs',
		'dQualGR',
		'dQualif',
		'dQulExEn',
		'dQulFlow',
		'dQulProc',
		'dQulSto',
		'dResourc',
		'dResProc',
		'dStamp',
		'dStampGR',
		'dStore',
		'dStoreGR',
		'dStorPrs',
		'dZone',
		'rActCat',
		'rAction',
		'rAttrSet',
		'rBlkCfg',
		'rChoice',
		'rChoiceG',
		'rChoiLnG',
		'rColAct',
		'rColumn',
		'rColVal',
		'rCombCol',
		'rCombDir',
		'rCombin',
		'rCompTbl',
		'rConcAcc',
		'rConnect',
		'rConnG',
		'rConnvG',
		'rConstr',
		'rContent',
		'rDatabas',
		'rDescAcc',
		'rDiagram',
		'rDim',
		'rDirect',
		'rErrMsg',
		'rFigure',
		'rFigureG',
		'rFile',
		'rFilSgrp',
		'rFilTbsp',
		'rFont',
		'rGraphic',
		'rIBICol',
		'rIBIDir',
		'rIBILink',
		'rIBILoc',
		'rIBIMFD',
		'rIBISec',
		'rIBITab',
		'rIndex',
		'rIndTbsp',
		'rLabelG',
		'rLine',
		'rLineG',
		'rMDIndex',
		'rPart',
		'rPictG',
		'rPicture',
		'rProc',
		'rRelCol',
		'rRollSeg',
		'rSDColn',
		'rSDFld',
		'rSDFldVl',
		'rSeq',
		'rSpecSym',
		'rStamp',
		'rStampG',
		'rStoCfg',
		'rStogrp',
		'rSubZone',
		'rSvwCol',
		'rSvwFmt',
		'rTable',
		'rTableG',
		'rTabspc',
		'rTabTbsp',
		'rText',
		'rTextG',
		'rZone',
		'tImage',
		'tItgParm',
		'tLongTxt',
		'tPrtParm',
		'wBasType',
		'wCharact',
		'wComItem',
		'wCompCat',
		'wCompon',
		'wCompPrs',
		'wCorrCat',
		'wCorresp',
		'wDefault',
		'wDomain',
		'wDomPrs',
		'wDomVal',
		'wExtStru',
		'wItemPrs',
		'wNSRRep',
		'wProject',
		'wRepPrs',
		'wRepres',
		'wRule',
		'wSRRep',
		'wStruct',
		'wStruNod',
		'wStruPrs',
		'wSubStru',
		'wTargSys',
		'wTypePrs',
		'wUFldVal',
		'wUser',
		'wUserFld',
		'zChkTran',
		'zChkUsed',
		'zConnect',
		'zControl',
		'zModule'
	)
	order by TABLE_NAME;
	 
/************************************************************************************
LIST OF SR_GUESTS'S PRIVILEGES WITHIN THE SILVERRUN REPOSITORY :
THERE SHOULD BE A LIST OF 150 TABLES */
select 	SUBSTR(TABLE_NAME,1,20) "TABLE NAME", SUBSTR(OWNER,1,20) "TABLE OWNER",
		SUBSTR(GRANTEE,1,20) "ROLE",
		SELECT_PRIV, INSERT_PRIV, UPDATE_PRIV, DELETE_PRIV
	from TABLE_PRIVILEGES
	where GRANTEE = 'SR_GUESTS'
	and TABLE_NAME in
	(
		'dCell',
		'dCpnProc',
		'dCpnStor',
		'dDiag',
		'dDispDes',
		'dExEnGR',
		'dExEnPrs',
		'dExtEnt',
		'dFigure',
		'dFigurGR',
		'dFlow',
		'dFlowGR',
		'dFont',
		'dFText',
		'dFTextGR',
		'dGrapRep',
		'dLabelGR',
		'dLine',
		'dLineGR',
		'dLinkGR',
		'dNode',
		'dPictGR',
		'dPicture',
		'dProcess',
		'dProcFrm',
		'dProcGR',
		'dProcPrs',
		'dQualGR',
		'dQualif',
		'dQulExEn',
		'dQulFlow',
		'dQulProc',
		'dQulSto',
		'dResourc',
		'dResProc',
		'dStamp',
		'dStampGR',
		'dStore',
		'dStoreGR',
		'dStorPrs',
		'dZone',
		'rActCat',
		'rAction',
		'rAttrSet',
		'rBlkCfg',
		'rChoice',
		'rChoiceG',
		'rChoiLnG',
		'rColAct',
		'rColumn',
		'rColVal',
		'rCombCol',
		'rCombDir',
		'rCombin',
		'rCompTbl',
		'rConcAcc',
		'rConnect',
		'rConnG',
		'rConnvG',
		'rConstr',
		'rContent',
		'rDatabas',
		'rDescAcc',
		'rDiagram',
		'rDim',
		'rDirect',
		'rErrMsg',
		'rFigure',
		'rFigureG',
		'rFile',
		'rFilSgrp',
		'rFilTbsp',
		'rFont',
		'rGraphic',
		'rIBICol',
		'rIBIDir',
		'rIBILink',
		'rIBILoc',
		'rIBIMFD',
		'rIBISec',
		'rIBITab',
		'rIndex',
		'rIndTbsp',
		'rLabelG',
		'rLine',
		'rLineG',
		'rMDIndex',
		'rPart',
		'rPictG',
		'rPicture',
		'rProc',
		'rRelCol',
		'rRollSeg',
		'rSDColn',
		'rSDFld',
		'rSDFldVl',
		'rSeq',
		'rSpecSym',
		'rStamp',
		'rStampG',
		'rStoCfg',
		'rStogrp',
		'rSubZone',
		'rSvwCol',
		'rSvwFmt',
		'rTable',
		'rTableG',
		'rTabspc',
		'rTabTbsp',
		'rText',
		'rTextG',
		'rZone',
		'tImage',
		'tItgParm',
		'tLongTxt',
		'tPrtParm',
		'wBasType',
		'wCharact',
		'wComItem',
		'wCompCat',
		'wCompon',
		'wCompPrs',
		'wCorrCat',
		'wCorresp',
		'wDefault',
		'wDomain',
		'wDomPrs',
		'wDomVal',
		'wExtStru',
		'wItemPrs',
		'wNSRRep',
		'wProject',
		'wRepPrs',
		'wRepres',
		'wRule',
		'wSRRep',
		'wStruct',
		'wStruNod',
		'wStruPrs',
		'wSubStru',
		'wTargSys',
		'wTypePrs',
		'wUFldVal',
		'wUser',
		'wUserFld',
		'zChkTran',
		'zChkUsed',
		'zConnect',
		'zControl',
		'zModule'
	)
	order by TABLE_NAME;
	 
/************************************************************************************
NUMBER OF TABLES IN THE SILVERRUN_REPOSITORY_DATA TABLESPACE :                     */
select COUNT(*) from DBA_TABLES where TABLESPACE_NAME = 'SILVERRUN_REPOSITORY_DATA';
 
/************************************************************************************
NUMBER OF INDEXES IN THE SILVERRUN_REPOSITORY_DATA TABLESPACES :                   */
select COUNT(*) from DBA_INDEXES where TABLESPACE_NAME = 'SILVERRUN_REPOSITORY_DATA';
 
/************************************************************************************
NUMBER OF INDEXES IN THE SILVERRUN_REPOSITORY_INDEXES TABLESPACES :                */
select COUNT(*) from DBA_INDEXES where TABLESPACE_NAME = 'SILVERRUN_REPOSITORY_INDEXES';



spool off;



drop table STATSRREP;

CREATE TABLE STATSRREP
( TYPE         VARCHAR2(3),
  SEGMENT      VARCHAR2(12),
  BYTES        NUMBER,
  EXT          NUMBER,
  INIT         VARCHAR2(8),
  NEXT         VARCHAR2(10),
  MIN          VARCHAR2(3),
  MAX          VARCHAR2(4),
  PCT_INC      VARCHAR2(3),
  TOTAL        NUMBER(8)
)   TABLESPACE SYSTEM
;

INSERT INTO STATSRREP(TYPE,SEGMENT,BYTES,EXT,INIT,NEXT,MIN,MAX,PCT_INC)
select SUBSTR(SEGMENT_TYPE,1,2),
       SUBSTR(SEGMENT_NAME,1,12),
       BYTES/1024,
       EXTENTS,
       TO_CHAR(INITIAL_EXTENT,999),
       TO_CHAR(NEXT_EXTENT,9999),
       TO_CHAR(MIN_EXTENTS,99),
       TO_CHAR(MAX_EXTENTS,999),
       TO_CHAR(PCT_INCREASE,99)
FROM DBA_SEGMENTS
WHERE OWNER = 'SR_ADMIN'
;

COMMIT;


update statsrrep set TOTAL = (select count(*) from sr_admin.dCell       ) where statsrrep.SEGMENT = upper('dCell');
update statsrrep set TOTAL = (select count(*) from sr_admin.dCpnProc    ) where statsrrep.SEGMENT = upper('dCpnProc');
update statsrrep set TOTAL = (select count(*) from sr_admin.dCpnStor    ) where statsrrep.SEGMENT = upper('dCpnStor');
update statsrrep set TOTAL = (select count(*) from sr_admin.dDiag       ) where statsrrep.SEGMENT = upper('dDiag');
update statsrrep set TOTAL = (select count(*) from sr_admin.dDispDes    ) where statsrrep.SEGMENT = upper('dDispDes');
update statsrrep set TOTAL = (select count(*) from sr_admin.dExEnGR     ) where statsrrep.SEGMENT = upper('dExEnGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dExEnPrs    ) where statsrrep.SEGMENT = upper('dExEnPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.dExtEnt     ) where statsrrep.SEGMENT = upper('dExtEnt');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFigure     ) where statsrrep.SEGMENT = upper('dFigure');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFigurGR    ) where statsrrep.SEGMENT = upper('dFigurGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFlow       ) where statsrrep.SEGMENT = upper('dFlow');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFlowGR     ) where statsrrep.SEGMENT = upper('dFlowGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFont       ) where statsrrep.SEGMENT = upper('dFont');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFText      ) where statsrrep.SEGMENT = upper('dFText');
update statsrrep set TOTAL = (select count(*) from sr_admin.dFTextGR    ) where statsrrep.SEGMENT = upper('dFTextGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dGrapRep    ) where statsrrep.SEGMENT = upper('dGrapRep');
update statsrrep set TOTAL = (select count(*) from sr_admin.dLabelGR    ) where statsrrep.SEGMENT = upper('dLabelGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dLine       ) where statsrrep.SEGMENT = upper('dLine');
update statsrrep set TOTAL = (select count(*) from sr_admin.dLineGR     ) where statsrrep.SEGMENT = upper('dLineGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dLinkGR     ) where statsrrep.SEGMENT = upper('dLinkGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dNode       ) where statsrrep.SEGMENT = upper('dNode');
update statsrrep set TOTAL = (select count(*) from sr_admin.dPictGR     ) where statsrrep.SEGMENT = upper('dPictGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dPicture    ) where statsrrep.SEGMENT = upper('dPicture');
update statsrrep set TOTAL = (select count(*) from sr_admin.dProcess    ) where statsrrep.SEGMENT = upper('dProcess');
update statsrrep set TOTAL = (select count(*) from sr_admin.dProcFrm    ) where statsrrep.SEGMENT = upper('dProcFrm');
update statsrrep set TOTAL = (select count(*) from sr_admin.dProcGR     ) where statsrrep.SEGMENT = upper('dProcGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dProcPrs    ) where statsrrep.SEGMENT = upper('dProcPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQualGR     ) where statsrrep.SEGMENT = upper('dQualGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQualif     ) where statsrrep.SEGMENT = upper('dQualif');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQulExEn    ) where statsrrep.SEGMENT = upper('dQulExEn');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQulFlow    ) where statsrrep.SEGMENT = upper('dQulFlow');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQulProc    ) where statsrrep.SEGMENT = upper('dQulProc');
update statsrrep set TOTAL = (select count(*) from sr_admin.dQulSto     ) where statsrrep.SEGMENT = upper('dQulSto');
update statsrrep set TOTAL = (select count(*) from sr_admin.dResourc    ) where statsrrep.SEGMENT = upper('dResourc');
update statsrrep set TOTAL = (select count(*) from sr_admin.dResProc    ) where statsrrep.SEGMENT = upper('dResProc');
update statsrrep set TOTAL = (select count(*) from sr_admin.dStamp      ) where statsrrep.SEGMENT = upper('dStamp');
update statsrrep set TOTAL = (select count(*) from sr_admin.dStampGR    ) where statsrrep.SEGMENT = upper('dStampGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dStore      ) where statsrrep.SEGMENT = upper('dStore');
update statsrrep set TOTAL = (select count(*) from sr_admin.dStoreGR    ) where statsrrep.SEGMENT = upper('dStoreGR');
update statsrrep set TOTAL = (select count(*) from sr_admin.dStorPrs    ) where statsrrep.SEGMENT = upper('dStorPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.dZone       ) where statsrrep.SEGMENT = upper('dZone');
update statsrrep set TOTAL = (select count(*) from sr_admin.rActCat     ) where statsrrep.SEGMENT = upper('rActCat');
update statsrrep set TOTAL = (select count(*) from sr_admin.rAction     ) where statsrrep.SEGMENT = upper('rAction');
update statsrrep set TOTAL = (select count(*) from sr_admin.rAttrSet    ) where statsrrep.SEGMENT = upper('rAttrSet');
update statsrrep set TOTAL = (select count(*) from sr_admin.rBlkCfg     ) where statsrrep.SEGMENT = upper('rBlkCfg');
update statsrrep set TOTAL = (select count(*) from sr_admin.rChoice     ) where statsrrep.SEGMENT = upper('rChoice');
update statsrrep set TOTAL = (select count(*) from sr_admin.rChoiceG    ) where statsrrep.SEGMENT = upper('rChoiceG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rChoiLnG    ) where statsrrep.SEGMENT = upper('rChoiLnG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rColAct     ) where statsrrep.SEGMENT = upper('rColAct');
update statsrrep set TOTAL = (select count(*) from sr_admin.rColumn     ) where statsrrep.SEGMENT = upper('rColumn');
update statsrrep set TOTAL = (select count(*) from sr_admin.rColVal     ) where statsrrep.SEGMENT = upper('rColVal');
update statsrrep set TOTAL = (select count(*) from sr_admin.rCombCol    ) where statsrrep.SEGMENT = upper('rCombCol');
update statsrrep set TOTAL = (select count(*) from sr_admin.rCombDir    ) where statsrrep.SEGMENT = upper('rCombDir');
update statsrrep set TOTAL = (select count(*) from sr_admin.rCombin     ) where statsrrep.SEGMENT = upper('rCombin');
update statsrrep set TOTAL = (select count(*) from sr_admin.rCompTbl    ) where statsrrep.SEGMENT = upper('rCompTbl');
update statsrrep set TOTAL = (select count(*) from sr_admin.rConcAcc    ) where statsrrep.SEGMENT = upper('rConcAcc');
update statsrrep set TOTAL = (select count(*) from sr_admin.rConnect    ) where statsrrep.SEGMENT = upper('rConnect');
update statsrrep set TOTAL = (select count(*) from sr_admin.rConnG      ) where statsrrep.SEGMENT = upper('rConnG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rConnvG     ) where statsrrep.SEGMENT = upper('rConnvG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rConstr     ) where statsrrep.SEGMENT = upper('rConstr');
update statsrrep set TOTAL = (select count(*) from sr_admin.rContent    ) where statsrrep.SEGMENT = upper('rContent');
update statsrrep set TOTAL = (select count(*) from sr_admin.rDatabas    ) where statsrrep.SEGMENT = upper('rDatabas');
update statsrrep set TOTAL = (select count(*) from sr_admin.rDescAcc    ) where statsrrep.SEGMENT = upper('rDescAcc');
update statsrrep set TOTAL = (select count(*) from sr_admin.rDiagram    ) where statsrrep.SEGMENT = upper('rDiagram');
update statsrrep set TOTAL = (select count(*) from sr_admin.rDim        ) where statsrrep.SEGMENT = upper('rDim');
update statsrrep set TOTAL = (select count(*) from sr_admin.rDirect     ) where statsrrep.SEGMENT = upper('rDirect');
update statsrrep set TOTAL = (select count(*) from sr_admin.rErrMsg     ) where statsrrep.SEGMENT = upper('rErrMsg');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFigure     ) where statsrrep.SEGMENT = upper('rFigure');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFigureG    ) where statsrrep.SEGMENT = upper('rFigureG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFile       ) where statsrrep.SEGMENT = upper('rFile');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFilSgrp    ) where statsrrep.SEGMENT = upper('rFilSgrp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFilTbsp    ) where statsrrep.SEGMENT = upper('rFilTbsp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rFont       ) where statsrrep.SEGMENT = upper('rFont');
update statsrrep set TOTAL = (select count(*) from sr_admin.rGraphic    ) where statsrrep.SEGMENT = upper('rGraphic');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBICol     ) where statsrrep.SEGMENT = upper('rIBICol');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBIDir     ) where statsrrep.SEGMENT = upper('rIBIDir');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBILink    ) where statsrrep.SEGMENT = upper('rIBILink');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBILoc     ) where statsrrep.SEGMENT = upper('rIBILoc');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBIMFD     ) where statsrrep.SEGMENT = upper('rIBIMFD');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBISec     ) where statsrrep.SEGMENT = upper('rIBISec');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIBITab     ) where statsrrep.SEGMENT = upper('rIBITab');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIndex      ) where statsrrep.SEGMENT = upper('rIndex');
update statsrrep set TOTAL = (select count(*) from sr_admin.rIndTbsp    ) where statsrrep.SEGMENT = upper('rIndTbsp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rLabelG     ) where statsrrep.SEGMENT = upper('rLabelG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rLine       ) where statsrrep.SEGMENT = upper('rLine');
update statsrrep set TOTAL = (select count(*) from sr_admin.rLineG      ) where statsrrep.SEGMENT = upper('rLineG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rMDIndex    ) where statsrrep.SEGMENT = upper('rMDIndex');
update statsrrep set TOTAL = (select count(*) from sr_admin.rPart       ) where statsrrep.SEGMENT = upper('rPart');
update statsrrep set TOTAL = (select count(*) from sr_admin.rPictG      ) where statsrrep.SEGMENT = upper('rPictG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rPicture    ) where statsrrep.SEGMENT = upper('rPicture');
update statsrrep set TOTAL = (select count(*) from sr_admin.rProc       ) where statsrrep.SEGMENT = upper('rProc');
update statsrrep set TOTAL = (select count(*) from sr_admin.rRelCol     ) where statsrrep.SEGMENT = upper('rRelCol');
update statsrrep set TOTAL = (select count(*) from sr_admin.rRollSeg    ) where statsrrep.SEGMENT = upper('rRollSeg');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSDColn     ) where statsrrep.SEGMENT = upper('rSDColn');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSDFld      ) where statsrrep.SEGMENT = upper('rSDFld');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSDFldVl    ) where statsrrep.SEGMENT = upper('rSDFldVl');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSeq        ) where statsrrep.SEGMENT = upper('rSeq');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSpecSym    ) where statsrrep.SEGMENT = upper('rSpecSym');
update statsrrep set TOTAL = (select count(*) from sr_admin.rStamp      ) where statsrrep.SEGMENT = upper('rStamp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rStampG     ) where statsrrep.SEGMENT = upper('rStampG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rStoCfg     ) where statsrrep.SEGMENT = upper('rStoCfg');
update statsrrep set TOTAL = (select count(*) from sr_admin.rStogrp     ) where statsrrep.SEGMENT = upper('rStogrp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSubZone    ) where statsrrep.SEGMENT = upper('rSubZone');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSvwCol     ) where statsrrep.SEGMENT = upper('rSvwCol');
update statsrrep set TOTAL = (select count(*) from sr_admin.rSvwFmt     ) where statsrrep.SEGMENT = upper('rSvwFmt');
update statsrrep set TOTAL = (select count(*) from sr_admin.rTable      ) where statsrrep.SEGMENT = upper('rTable');
update statsrrep set TOTAL = (select count(*) from sr_admin.rTableG     ) where statsrrep.SEGMENT = upper('rTableG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rTabspc     ) where statsrrep.SEGMENT = upper('rTabspc');
update statsrrep set TOTAL = (select count(*) from sr_admin.rTabTbsp    ) where statsrrep.SEGMENT = upper('rTabTbsp');
update statsrrep set TOTAL = (select count(*) from sr_admin.rText       ) where statsrrep.SEGMENT = upper('rText');
update statsrrep set TOTAL = (select count(*) from sr_admin.rTextG      ) where statsrrep.SEGMENT = upper('rTextG');
update statsrrep set TOTAL = (select count(*) from sr_admin.rZone       ) where statsrrep.SEGMENT = upper('rZone');
update statsrrep set TOTAL = (select count(*) from sr_admin.tImage      ) where statsrrep.SEGMENT = upper('tImage');
update statsrrep set TOTAL = (select count(*) from sr_admin.tItgParm    ) where statsrrep.SEGMENT = upper('tItgParm');
update statsrrep set TOTAL = (select count(*) from sr_admin.tLongTxt    ) where statsrrep.SEGMENT = upper('tLongTxt');
update statsrrep set TOTAL = (select count(*) from sr_admin.tPrtParm    ) where statsrrep.SEGMENT = upper('tPrtParm');
update statsrrep set TOTAL = (select count(*) from sr_admin.wBasType    ) where statsrrep.SEGMENT = upper('wBasType');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCharact    ) where statsrrep.SEGMENT = upper('wCharact');
update statsrrep set TOTAL = (select count(*) from sr_admin.wComItem    ) where statsrrep.SEGMENT = upper('wComItem');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCompCat    ) where statsrrep.SEGMENT = upper('wCompCat');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCompon     ) where statsrrep.SEGMENT = upper('wCompon');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCompPrs    ) where statsrrep.SEGMENT = upper('wCompPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCorrCat    ) where statsrrep.SEGMENT = upper('wCorrCat');
update statsrrep set TOTAL = (select count(*) from sr_admin.wCorresp    ) where statsrrep.SEGMENT = upper('wCorresp');
update statsrrep set TOTAL = (select count(*) from sr_admin.wDefault    ) where statsrrep.SEGMENT = upper('wDefault');
update statsrrep set TOTAL = (select count(*) from sr_admin.wDomain     ) where statsrrep.SEGMENT = upper('wDomain');
update statsrrep set TOTAL = (select count(*) from sr_admin.wDomPrs     ) where statsrrep.SEGMENT = upper('wDomPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wDomVal     ) where statsrrep.SEGMENT = upper('wDomVal');
update statsrrep set TOTAL = (select count(*) from sr_admin.wExtStru    ) where statsrrep.SEGMENT = upper('wExtStru');
update statsrrep set TOTAL = (select count(*) from sr_admin.wItemPrs    ) where statsrrep.SEGMENT = upper('wItemPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wNSRRep     ) where statsrrep.SEGMENT = upper('wNSRRep');
update statsrrep set TOTAL = (select count(*) from sr_admin.wProject    ) where statsrrep.SEGMENT = upper('wProject');
update statsrrep set TOTAL = (select count(*) from sr_admin.wRepPrs     ) where statsrrep.SEGMENT = upper('wRepPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wRepres     ) where statsrrep.SEGMENT = upper('wRepres');
update statsrrep set TOTAL = (select count(*) from sr_admin.wRule       ) where statsrrep.SEGMENT = upper('wRule');
update statsrrep set TOTAL = (select count(*) from sr_admin.wSRRep      ) where statsrrep.SEGMENT = upper('wSRRep');
update statsrrep set TOTAL = (select count(*) from sr_admin.wStruct     ) where statsrrep.SEGMENT = upper('wStruct');
update statsrrep set TOTAL = (select count(*) from sr_admin.wStruNod    ) where statsrrep.SEGMENT = upper('wStruNod');
update statsrrep set TOTAL = (select count(*) from sr_admin.wStruPrs    ) where statsrrep.SEGMENT = upper('wStruPrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wSubStru    ) where statsrrep.SEGMENT = upper('wSubStru');
update statsrrep set TOTAL = (select count(*) from sr_admin.wTargSys    ) where statsrrep.SEGMENT = upper('wTargSys');
update statsrrep set TOTAL = (select count(*) from sr_admin.wTypePrs    ) where statsrrep.SEGMENT = upper('wTypePrs');
update statsrrep set TOTAL = (select count(*) from sr_admin.wUFldVal    ) where statsrrep.SEGMENT = upper('wUFldVal');
update statsrrep set TOTAL = (select count(*) from sr_admin.wUser       ) where statsrrep.SEGMENT = upper('wUser');
update statsrrep set TOTAL = (select count(*) from sr_admin.wUserFld    ) where statsrrep.SEGMENT = upper('wUserFld');
update statsrrep set TOTAL = (select count(*) from sr_admin.zChkTran    ) where statsrrep.SEGMENT = upper('zChkTran');
update statsrrep set TOTAL = (select count(*) from sr_admin.zChkUsed    ) where statsrrep.SEGMENT = upper('zChkUsed');
update statsrrep set TOTAL = (select count(*) from sr_admin.zConnect    ) where statsrrep.SEGMENT = upper('zConnect');
update statsrrep set TOTAL = (select count(*) from sr_admin.zControl    ) where statsrrep.SEGMENT = upper('zControl');
update statsrrep set TOTAL = (select count(*) from sr_admin.zModule     ) where statsrrep.SEGMENT = upper('zModule');



COMMIT;

COLUMN EXT HEADING "TOTAL|EXTENTS";
COLUMN INIT HEADING "INITIAL|EXTENT|(BLOCKS)";
COLUMN NEXT HEADING "NEXT|EXTENT|(BLOCKS)";
COLUMN TOTAL HEADING "TOTAL|ROWS";
COLUMN MIN HEADING "MIN|EXT";
COLUMN MAX HEADING "MAX|EXT";
COLUMN BYTES FORMAT 999,999,999;
COLUMN BYTES HEADING "TOTAL KB|ALLOCATED";
COLUMN SEGMENT HEADING "OBJECT NAME";
BREAK ON TYPE SKIP 3 ON REPORT;
COMPUTE SUM OF BYTES ON TYPE;
COMPUTE SUM OF EXT ON TYPE;
COMPUTE SUM OF BYTES ON REPORT;
COMPUTE SUM OF EXT ON REPORT;

spool repspace.lst
 
/************************************************************************************
REPORT ON SPACE ALLOCATED FOR THE SILVERRUN REPOSITORY BY OBJECT OWNED BY SR_ADMIN:*/

SELECT 'SCRIPT EXECUTED ON '||SYSDATE " " FROM DUAL;


SELECT * FROM STATSRREP
ORDER BY TYPE DESC, BYTES DESC, SEGMENT;

spool off;


COLUMN EXT CLEAR;
COLUMN INIT CLEAR;
COLUMN NEXT CLEAR;
COLUMN TOTAL CLEAR;
COLUMN MIN CLEAR;
COLUMN MAX CLEAR;
COLUMN SEGMENT CLEAR;
COLUMN BYTES CLEAR;

drop table STATSRREP;


set pagesize 14;
set echo on;
